@@ -4,7 +4,7 @@
     This file is part of Corrade.
 
     Copyright © 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
-                2017, 2018 Vladimír Vondruš <mosra@centrum.cz>
+                2017, 2018, 2019 Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
     copy of this software and associated documentation files (the "Software"),
@@ -26,12 +26,13 @@
 */
 
 /* #undef CORRADE_BIG_ENDIAN */
-/* #undef CORRADE_GCC47_COMPATIBILITY */
+/* #undef CORRADE_MSVC2019_COMPATIBILITY */
 /* #undef CORRADE_MSVC2017_COMPATIBILITY */
 /* #undef CORRADE_MSVC2015_COMPATIBILITY */
 
 #define CORRADE_BUILD_DEPRECATED
 /* #undef CORRADE_BUILD_STATIC */
+#define CORRADE_BUILD_MULTITHREADED
 
 /* #undef CORRADE_TARGET_APPLE */
 /* #undef CORRADE_TARGET_IOS */
@@ -42,6 +43,7 @@
 /* #undef CORRADE_TARGET_EMSCRIPTEN */
 /* #undef CORRADE_TARGET_ANDROID */
 
+/* #undef CORRADE_PLUGINMANAGER_NO_DYNAMIC_PLUGIN_SUPPORT */
 /* #undef CORRADE_TESTSUITE_TARGET_XCTEST */
 /* #undef CORRADE_UTILITY_USE_ANSI_COLORS */
 
@@ -59,6 +61,10 @@
 #elif defined(__arm__) || defined(__aarch64__) || defined(_M_ARM) || defined(_M_ARM64)
 #define CORRADE_TARGET_ARM
 
+/* First is GCC/Clang, second is MSVC */
+#elif defined(__powerpc64__) || defined(_M_PPC)
+#define CORRADE_TARGET_POWERPC
+
 /* Otherwise one should expect CORRADE_TARGET_EMSCRIPTEN. No other platforms
    are currently tested for, but that's okay -- a runtime test for this is in
    Utility/Test/SystemTest.cpp */
@@ -66,7 +72,43 @@
 
 /* Sanity checks */
 #if defined(CORRADE_TARGET_EMSCRIPTEN) && (defined(CORRADE_TARGET_X86) || defined(CORRADE_TARGET_ARM))
-#error CORRADE_TARGET_X86 or CORRADE_TARGET_ARM defined on Emscripten
+#error CORRADE_TARGET_X86 / _ARM / _POWERPC defined on Emscripten
+#endif
+
+/* C++ standard */
+#ifdef _MSC_VER
+#ifdef _MSVC_LANG
+#define CORRADE_CXX_STANDARD _MSVC_LANG
+#else
+#define CORRADE_CXX_STANDARD 201103L
+#endif
+#else
+#define CORRADE_CXX_STANDARD __cplusplus
+#endif
+
+/* Standard library edition. Keep in sync with CorradeStl* singles. References:
+   https://gcc.gnu.org/bugzilla/show_bug.cgi?id=65473
+   https://github.com/gcc-mirror/gcc/commit/19665740d336d4ee7d0cf92b5b0643fa1d7da14a
+   https://en.cppreference.com/w/cpp/header/ciso646 */
+#include <ciso646>
+#ifdef _LIBCPP_VERSION
+#define CORRADE_TARGET_LIBCXX
+#elif defined(_CPPLIB_VER)
+#define CORRADE_TARGET_DINKUMWARE
+#elif defined(__GLIBCXX__)
+#define CORRADE_TARGET_LIBSTDCXX
+/* GCC's <ciso646> provides the __GLIBCXX__ macro only since 6.1, so on older
+   versions we'll try to get it from bits/c++config.h. GCC < 5.0 doesn't have
+   __has_include, so on these versions we'll give up completely. */
+#elif defined(__has_include)
+    #if __has_include(<bits/c++config.h>)
+        #include <bits/c++config.h>
+        #ifdef __GLIBCXX__
+        #define CORRADE_TARGET_LIBSTDCXX
+        #endif
+    #endif
+#else
+/* Otherwise no idea. */
 #endif
 
 #endif
